@@ -212,7 +212,7 @@ bool block::transAsTemplatedField(
   if (!dec) {
     em.error(getPos());
     em << "expected 'typedef import(<types>);'";
-    em.sync();
+    em.sync(true);
     return false;
   }
   if(!dec->transAsParamMatcher(e, r, args, caller))
@@ -888,7 +888,7 @@ varEntry *accessModule(position pos, coenv &e, record *r, symbol id)
   if (!imp) {
     em.error(pos);
     em << "could not load module '" << filename << "'";
-    em.sync();
+    em.sync(true);
     return 0;
   }
   else {
@@ -923,7 +923,7 @@ varEntry *accessTemplatedModule(position pos, coenv &e, record *r, symbol id,
     if (theName == symbol::nullsym) {
       em.error(theType->getPos());
       em << "expected typename=";
-      em.sync();
+      em.sync(true);
       return nullptr;
     }
     computedArgs->push_back(new namedTyEntry(
@@ -935,7 +935,7 @@ varEntry *accessTemplatedModule(position pos, coenv &e, record *r, symbol id,
   if (!imp) {
     em.error(pos);
     em << "could not load module '" << id << "'";
-    em.sync();
+    em.sync(true);
     return nullptr;
   }
   else {
@@ -1246,7 +1246,7 @@ void receiveTypedefDec::transAsField(coenv& e, record *r) {
   } else {
     em << "templated module access requires template parameters";
   }
-  em.sync();
+  em.sync(true);
 }
 
 
@@ -1375,7 +1375,7 @@ void includedec::loadFailed(coenv &)
 {
   em.warning(getPos());
   em << "could not parse file of name '" << filename << "'";
-  em.sync();
+  em.sync(true);
 }
 
 void includedec::transAsField(coenv &e, record *r)
