@@ -1323,6 +1323,7 @@ struct Communicate : public gc {
   pair shift;
   pair margin;
   double *t;
+  double *tup;
   double *background;
   size_t nlights;
   triple *lights;
@@ -1344,15 +1345,17 @@ void glrenderWrapper()
 #endif
   if(allowRender)
     glrender(com.prefix,com.pic,com.format,com.width,com.height,com.angle,
-             com.zoom,com.m,com.M,com.shift,com.margin,com.t,com.background,
-             com.nlights,com.lights,com.diffuse,com.specular,com.view);
+             com.zoom,com.m,com.M,com.shift,com.margin,com.t,com.tup,
+             com.background,com.nlights,com.lights,com.diffuse,com.specular,
+             com.view);
 #endif
 }
 
 bool picture::shipout3(const string& prefix, const string& format,
                        double width, double height, double angle, double zoom,
                        const triple& m, const triple& M, const pair& shift,
-                       const pair& margin, double *t, double *background,
+                       const pair& margin, double *t, double *tup,
+                       double *background,
                        size_t nlights, triple *lights, double *diffuse,
                        double *specular, bool view)
 {
@@ -1444,6 +1447,7 @@ bool picture::shipout3(const string& prefix, const string& format,
         com.shift=shift;
         com.margin=margin;
         com.t=t;
+        com.tup=tup;
         com.background=background;
         com.nlights=nlights;
         com.lights=lights;
@@ -1483,8 +1487,8 @@ bool picture::shipout3(const string& prefix, const string& format,
   }
 
 #if HAVE_LIBGLM
-  glrender(prefix,pic,outputformat,width,height,angle,zoom,m,M,shift,margin,t,
-           background,nlights,lights,diffuse,specular,View,oldpid);
+  glrender(prefix,pic,outputformat,width,height,angle,zoom,m,M,shift,margin,
+           t,tup,background,nlights,lights,diffuse,specular,View,oldpid);
 
   if(format3d) {
     string name=buildname(prefix,format);
